==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/uk.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Документи",
"Can't create document" => "Неможливо створити документ",
"You don't have permission to rename this document" => "Вам бракує прав на зміну імені цього документу",
"Directory saved successfully." => "Директорію збережено.",
"An error occurred while changing directory." => "При зміні теки виникла помилка.",
"Saved" => "Збереженно",
"Format filter server is down or misconfigured" => "Сервер фільтрації формату не працює або налаштований невірно",
"Conversion failed. Check log for details." => "Конвертація не вдалася. За деталями зверніться до журналу.",
"Saving..." => "Зберігаю...",
"Failed to load documents." => "Не вдалося завантажити документи.",
"No documents were found. Upload or create a document to get started!" => "Документів не знайдено. Завантажте або створіть новий документ для початку!",
"No connection to server. Trying to reconnect." => "Немає з'єднання з сервером. Підключаємось заново.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Покинувши цю сторінку в режимі Редактора ви можете втратити деякі дані. Для збереження даних рекомендуємо використовувати кнопку \"Закрити\".",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Не вдалося завантажити документ. Будь ласка, перевірте чи не відкритий він зовнішнім odt редактором.",
"Save" => "Зберегти",
"Loading documents..." => "Завантаження документів...",
"'.' is an invalid file name." => "'.' це невірне ім'я файлу.",
"File name cannot be empty." => " Ім'я файлу не може бути порожнім.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Невірне ім'я, '\\', '/', '<', '>', ':', '\"', '|', '?' та '*' не дозволені.",
"Align Left" => "За лівим краєм",
"Alignment" => "Вирівнювання",
"Align Right" => "За правим краєм",
"Annotate" => "Анотувати",
"Background" => "Фон",
"Bold" => "Жирний",
"Bottom" => "Низ",
"Cancel" => "Відмінити",
"Center" => "Центр",
"Clone" => "Клонувати",
"Clone this Style" => "Клонувати цей стиль",
"Close" => "Закрити",
"Color" => "Колір",
"Create" => "Створити",
"Decrease Indent" => "Зменшити відступ",
"Default Style" => "Стиль за замовчуванням",
"Delete" => "Видалити",
"Family" => "Сім'я",
"Font" => "Шрифт",
"Font Effects" => "Шрифтові Ефекти",
"Format" => "Формат",
"Increase Indent" => "Збільшити відступ",
"Insert Image" => "Вставити зображення",
"Invite Members" => "Запросити учасників",
"Italic" => "Курсив",
"Justified" => "За шириною",
"Justify" => "Вирівняти за шириною",
"Left" => "Ліворуч",
"Loading" => "Завантаження",
"Members" => "Учасники",
"New Name:" => "Нове Ім'я:",
"OK" => "OK",
"Open" => "Відкрити",
"Options" => "Опції",
"Paragraph..." => "Абзац...",
"Paragraph Styles" => "Стилі абзацу...",
"Redo" => "Повторити",
"Right" => "Праворуч",
"Size" => "Розмір",
"Spacing" => "Міжрядковий інтервал",
"Strikethrough" => "Закреслений",
"Style" => "Стиль",
"Text" => "Текст",
"Top" => "Верх",
"Underline" => "Підкреслений",
"Undo" => "Скасувати",
"Unknown Author" => "Невідомий Автор",
"Edit" => "Редагувати",
"Share" => "Поділитися",
"guest" => "гість",
"MS Word support (requires openOffice/libreOffice)" => "Підтримується MS Word (потрібен openOffice або libreOffice)",
"Local" => "Локально",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice або libreOffice встановлено на цьому сервері. Шлях до бінарних файлів налаштовується змінною via preview_libreoffice_path в файлі config.php",
"External" => "Зовнішній",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice або libreOffice встановлено на зовнішньому сервері який виконує форматування та фільтрацію",
"Disabled" => "Вимкнено",
"No MS Word support" => "MS Word не підтримується",
"scheme://domain.tld[:port]" => "протокол://домен.зона[:порт]",
"Server URL" => "URL сервера",
"Apply and test" => "Застосувати та спробувати",
"New document" => "Новий документ",
"Upload (max. %s)" => "Завантаження (макс. %s)",
"Upload" => "Вивантажити",
"Save new documents to" => "Зберегти новий документ до",
"Wrong password. Please retry." => "Невірний пароль. Будь ласка, спробуйте ще раз.",
"Password" => "Пароль",
"Guest %s" => "Гість %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Строк дії цього посилання скінчився, або воно ніколи не існувало. Будь ласка, зверніться до особи, що поділилася нею, за подробицями.",
"Advanced feature-set" => "Розширені функції",
"(Unstable)" => "(Нестабільно)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/uk.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Документи",
"Can't create document" => "Неможливо створити документ",
"You don't have permission to rename this document" => "Вам бракує прав на зміну імені цього документу",
"Directory saved successfully." => "Директорію збережено.",
"An error occurred while changing directory." => "При зміні теки виникла помилка.",
"Saved" => "Збереженно",
"Format filter server is down or misconfigured" => "Сервер фільтрації формату не працює або налаштований невірно",
"Conversion failed. Check log for details." => "Конвертація не вдалася. За деталями зверніться до журналу.",
"Saving..." => "Зберігаю...",
"Failed to load documents." => "Не вдалося завантажити документи.",
"No documents were found. Upload or create a document to get started!" => "Документів не знайдено. Завантажте або створіть новий документ для початку!",
"No connection to server. Trying to reconnect." => "Немає з'єднання з сервером. Підключаємось заново.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Покинувши цю сторінку в режимі Редактора ви можете втратити деякі дані. Для збереження даних рекомендуємо використовувати кнопку \"Закрити\".",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Не вдалося завантажити документ. Будь ласка, перевірте чи не відкритий він зовнішнім odt редактором.",
"Save" => "Зберегти",
"Loading documents..." => "Завантаження документів...",
"'.' is an invalid file name." => "'.' це невірне ім'я файлу.",
"File name cannot be empty." => " Ім'я файлу не може бути порожнім.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Невірне ім'я, '\\', '/', '<', '>', ':', '\"', '|', '?' та '*' не дозволені.",
"Align Left" => "За лівим краєм",
"Alignment" => "Вирівнювання",
"Align Right" => "За правим краєм",
"Annotate" => "Анотувати",
"Background" => "Фон",
"Bold" => "Жирний",
"Bottom" => "Низ",
"Cancel" => "Відмінити",
"Center" => "Центр",
"Clone" => "Клонувати",
"Clone this Style" => "Клонувати цей стиль",
"Close" => "Закрити",
"Color" => "Колір",
"Create" => "Створити",
"Decrease Indent" => "Зменшити відступ",
"Default Style" => "Стиль за замовчуванням",
"Delete" => "Видалити",
"Family" => "Сім'я",
"Font" => "Шрифт",
"Font Effects" => "Шрифтові Ефекти",
"Format" => "Формат",
"Increase Indent" => "Збільшити відступ",
"Insert Image" => "Вставити зображення",
"Invite Members" => "Запросити учасників",
"Italic" => "Курсив",
"Justified" => "За шириною",
"Justify" => "Вирівняти за шириною",
"Left" => "Ліворуч",
"Loading" => "Завантаження",
"Members" => "Учасники",
"New Name:" => "Нове Ім'я:",
"OK" => "OK",
"Open" => "Відкрити",
"Options" => "Опції",
"Paragraph..." => "Абзац...",
"Paragraph Styles" => "Стилі абзацу...",
"Redo" => "Повторити",
"Right" => "Праворуч",
"Size" => "Розмір",
"Spacing" => "Міжрядковий інтервал",
"Strikethrough" => "Закреслений",
"Style" => "Стиль",
"Text" => "Текст",
"Top" => "Верх",
"Underline" => "Підкреслений",
"Undo" => "Скасувати",
"Unknown Author" => "Невідомий Автор",
"Shared" => "Опубліковано",
"Error" => "Помилка",
"Error while sharing" => "Помилка під час публікації",
"Error while unsharing" => "Помилка під час відміни публікації",
"Error while changing permissions" => "Помилка при зміні повноважень",
"Shared with you and the group {group} by {owner}" => " {owner} опублікував для Вас та для групи {group}",
"Shared with you by {owner}" => "{owner} опублікував для Вас",
"Share with users or groups …" => "Поширити серед користувачів або груп ...",
"Share with users, groups or remote users …" => "Поширити серед локальних чи віддалених користувачів або груп ...",
"Share" => "Поділитися",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Поширити серед людей інших ownCloud'ів, використовуючи синтаксис ім'я_користувача@файли.укр/owncloud",
"Share link" => "Поділитись посиланням",
"The public link will expire no later than {days} days after it is created" => "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
"Link" => "Посилання",
"Password protect" => "Захистити паролем",
"Password" => "Пароль",
"Choose a password for the public link" => "Вкажіть пароль для публічного посилання",
"Allow editing" => "Дозволити редагування",
"Email link to person" => "Надіслати посилання електронною поштою",
"Send" => "Надіслати",
"Set expiration date" => "Встановити термін дії",
"Expiration" => "Закінчення",
"Expiration date" => "Термін дії",
"An error occured. Please try again" => "Виникла помилка. Будь ласка, спробуйте ще раз",
"Adding user..." => "Додавання користувача...",
"group" => "група",
"remote" => "Віддалений",
"Resharing is not allowed" => "Пере-публікація не дозволяється",
"Shared in {item} with {user}" => "Опубліковано {item} для {user}",
"Unshare" => "Закрити спільний доступ",
"notify by email" => "повідомити по Email",
"can share" => "може ділитися з іншими",
"can edit" => "може редагувати",
"access control" => "контроль доступу",
"create" => "створити",
"change" => "змінити",
"delete" => "видалити",
"Password protected" => "Захищено паролем",
"Error unsetting expiration date" => "Помилка при відміні терміну дії",
"Error setting expiration date" => "Помилка при встановленні терміну дії",
"Sending ..." => "Надсилання...",
"Email sent" => "Лист надіслано",
"Warning" => "Попередження",
"Edit" => "Редагувати",
"guest" => "гість",
"MS Word support (requires openOffice/libreOffice)" => "Підтримується MS Word (потрібен openOffice або libreOffice)",
"Local" => "Локально",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice або libreOffice встановлено на цьому сервері. Шлях до бінарних файлів налаштовується змінною via preview_libreoffice_path в файлі config.php",
"External" => "Зовнішній",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice або libreOffice встановлено на зовнішньому сервері який виконує форматування та фільтрацію",
"Disabled" => "Вимкнено",
"No MS Word support" => "MS Word не підтримується",
"scheme://domain.tld[:port]" => "протокол://домен.зона[:порт]",
"Server URL" => "URL сервера",
"Apply and test" => "Застосувати та спробувати",
"New document" => "Новий документ",
"Upload (max. %s)" => "Завантаження (макс. %s)",
"Upload" => "Вивантажити",
"Save new documents to" => "Зберегти новий документ до",
"Wrong password. Please retry." => "Невірний пароль. Будь ласка, спробуйте ще раз.",
"Guest %s" => "Гість %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Строк дії цього посилання скінчився, або воно ніколи не існувало. Будь ласка, зверніться до особи, що поділилася нею, за подробицями.",
"Advanced feature-set" => "Розширені функції",
"(Unstable)" => "(Нестабільно)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
